type Foo = {
};
function foo() {
    type Foo__2 = string | number;
    const foo__2 = {} as Foo__2;
}
const bar = {} as Foo;
